@@ -23,12 +23,12 @@
 #include <ctime>
 #include <algorithm>
 
-#include <qalgorithms.h>
+#include <QtAlgorithms>
 
 #include "../include/kdev-pg-location-table.h"
 
-#include <QtTest/QTest>
-#include <QtCore/QDebug>
+#include <QTest>
+#include <QDebug>
 
 using namespace std;
 
