@@ -21,7 +21,7 @@
 #ifndef TESTLOCATIONTABLE_H
 #define TESTLOCATIONTABLE_H
 
-#include <QtCore/qobject.h>
+#include <QObject>
 
 namespace KDevPG
 {
@@ -30,7 +30,7 @@ class TestLocationTable : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
 
     void underflow();
